FSharp.Data Namespace
Contains the primary types for the FSharp.Data package.
| Type/Module | Description |
|
|
|
|
Provides the dynamic operator for getting column values by name from CSV rows |
|
|
Represents a CSV file. The lines are read on demand from |
|
|
Typed representation of a CSV file. |
|
|
|
|
|
|
|
|
|
|
|
Represents an HTML attribute. The name is always normalized to lowercase |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Typed representation of an HTML file. |
|
|
Utilities for working with network via HTTP. Includes methods for downloading resources with specified headers, query parameters and HTTP body |
|
|
Constants for common HTTP content types |
|
|
Constants for common HTTP encodings |
|
|
The method to use in an HTTP request |
|
|
The body to send in an HTTP request |
|
|
Headers that can be sent in an HTTP request |
|
|
The response returned by an HTTP request |
|
|
The response body returned by an HTTP request |
|
|
Headers that can be received in an HTTP response |
|
|
The response returned by an HTTP request with direct access to the response stream |
|
|
Status codes that can be received in an HTTP response |
|
|
This is the public inference mode enum used when initializing a type provider, with backward compatibility. |
|
|
Provides the dynamic operator for getting a property of a JSON object |
|
|
Extension methods that can be used to work with JsonValue in a less safe, but more convenient way. This module also provides the dynamic operator. |
|
|
Typed representation of a JSON document. |
|
|
Specifies the formatting behaviour of JSON values |
|
|
|
|
|
Represents the result of validating a JSON value against a schema |
|
|
Represents a JSON value. Large numbers that do not fit in the Decimal type are represented using the Float case, while smaller numbers are represented as decimals to avoid precision loss. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Extension methods with conversions from strings to other types |
|
|
Conversions from string to string/int/int64/decimal/float/boolean/datetime/timespan/guid options |
|
|
|
|
|
Typed representation of WorldBank data with additional configuration parameters. See https://www.worldbank.org for terms and conditions. |
|
|
|
|
|
Typed representation of a XML file. |
FSharp.Data