CsvExtensions Module
Provides the dynamic operator for getting column values by name from CSV rows
Functions and values
| Function or value |
Description
|
|
Get the value of a column by name from a CSV row
|
FSharp.Data