HtmlDocumentExtensions Type
Static members
| Static member |
Description
|
|
Finds the body element of the given document, this throws an exception if no body element exists.
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc, name)
Parameters:
HtmlDocument
-
The given document
name : string
-
The name to match
Returns: HtmlNode seq
|
Finds all of the descendant nodes of this document that match the given name Recurses on match
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc, name, recurseOnMatch)
Parameters:
HtmlDocument
-
The given document
name : string
-
The name to match
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: HtmlNode seq
|
Finds all of the descendant nodes of this document that match the given name
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc, names)
Parameters:
HtmlDocument
-
The given document
names : string seq
-
The set of names to match
Returns: HtmlNode seq
|
Finds all of the descendant nodes of this document that match the given set of names Recurses on match
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc, names, recurseOnMatch)
Parameters:
HtmlDocument
-
The given document
names : string seq
-
The set of names to match
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: HtmlNode seq
|
Finds all of the descendant nodes of this document that match the given set of names
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc)
Parameters:
HtmlDocument
Returns: HtmlNode seq
|
Gets all of the descendants of this document Recurses on match
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc, predicate)
Parameters:
HtmlDocument
-
The given document
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
Returns: HtmlNode seq
|
Gets all of the descendants of this document that statisfy the given predicate Recurses on match
|
Full Usage:
HtmlDocumentExtensions.Descendants(doc, predicate, recurseOnMatch)
Parameters:
HtmlDocument
-
The given document
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: HtmlNode seq
|
Gets all of the descendants of this document that statisfy the given predicate
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc, name)
Parameters:
HtmlDocument
-
The given document
name : string
-
The name to match
Returns: (HtmlNode * HtmlNode list) seq
|
Finds all of the descendant nodes of this document that match the given name Recurses on match
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc, name, recurseOnMatch)
Parameters:
HtmlDocument
-
The given document
name : string
-
The name to match
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Finds all of the descendant nodes of this document that match the given name
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc, names)
Parameters:
HtmlDocument
-
The given document
names : string seq
-
The set of names to match
Returns: (HtmlNode * HtmlNode list) seq
|
Finds all of the descendant nodes of this document that match the given set of names Recurses on match
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc, names, recurseOnMatch)
Parameters:
HtmlDocument
-
The given document
names : string seq
-
The set of names to match
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Finds all of the descendant nodes of this document that match the given set of names
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc)
Parameters:
HtmlDocument
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of this document Recurses on match
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc, predicate)
Parameters:
HtmlDocument
-
The given document
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of this document that statisfy the given predicate Recurses on match
|
Full Usage:
HtmlDocumentExtensions.DescendantsWithPath(doc, predicate, recurseOnMatch)
Parameters:
HtmlDocument
-
The given document
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of this document that statisfy the given predicate
|
Full Usage:
HtmlDocumentExtensions.Elements(doc, name)
Parameters:
HtmlDocument
-
The given document
name : string
-
The name to match
Returns: HtmlNode list
|
Returns all of the root elements in the current document that match the name
|
Full Usage:
HtmlDocumentExtensions.Elements(doc, names)
Parameters:
HtmlDocument
-
The given document
names : string seq
-
The set of names to match
Returns: HtmlNode list
|
Returns all of the root elements in the current document that match the set of names
|
Full Usage:
HtmlDocumentExtensions.Elements(doc)
Parameters:
HtmlDocument
-
The given document
Returns: HtmlNode list
|
Returns all of the root elements of the current document
|
|
Finds the html element of the given document, this throws an exception if no html element exists.
|
Full Usage:
HtmlDocumentExtensions.TryGetBody(doc)
Parameters:
HtmlDocument
Returns: HtmlNode option
|
|
Full Usage:
HtmlDocumentExtensions.TryGetHtml(doc)
Parameters:
HtmlDocument
Returns: HtmlNode option
|
FSharp.Data