HtmlDocument Module
Functions and values
| Function or value |
Description
|
Full Usage:
body x
Parameters:
HtmlDocument
-
The given document
Returns: HtmlNode
Modifiers: inline |
Finds the body element of the given document, this throws an exception if no body element exists.
|
Full Usage:
descendants recurseOnMatch predicate doc
Parameters:
bool
-
If a match is found continues down the tree matching child elements
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
doc : HtmlDocument
-
The given document
Returns: HtmlNode seq
Modifiers: inline |
Gets all of the descendants of this document that statisfy the given predicate
|
Full Usage:
descendantsNamed recurseOnMatch names doc
Parameters:
bool
-
If a match is found continues down the tree matching child elements
names : string seq
-
The set of names to match
doc : HtmlDocument
-
The given document
Returns: HtmlNode seq
Modifiers: inline |
Finds all of the descendant nodes of this document that match the given set of names
|
Full Usage:
descendantsNamedWithPath recurseOnMatch names doc
Parameters:
bool
-
If a match is found continues down the tree matching child elements
names : string seq
-
The set of names to match
doc : HtmlDocument
-
The given document
Returns: (HtmlNode * HtmlNode list) seq
Modifiers: inline |
Finds all of the descendant nodes of this document that match the given set of names
|
Full Usage:
descendantsWithPath recurseOnMatch predicate doc
Parameters:
bool
-
If a match is found continues down the tree matching child elements
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
doc : HtmlDocument
-
The given document
Returns: (HtmlNode * HtmlNode list) seq
Modifiers: inline |
Gets all of the descendants of this document that statisfy the given predicate
|
|
|
|
|
Full Usage:
elementsNamed names doc
Parameters:
string seq
-
The set of names to match
doc : HtmlDocument
-
The given document
Returns: HtmlNode list
Modifiers: inline |
Returns all of the root elements of the document that match the set of names
|
Full Usage:
html x
Parameters:
HtmlDocument
-
The given document
Returns: HtmlNode
Modifiers: inline |
Finds the html element of the given document, this throws an exception if no html element exists.
|
Full Usage:
tryGetBody x
Parameters:
HtmlDocument
-
The given document
Returns: HtmlNode option
Modifiers: inline |
Tries to find the body element of the given document.
|
Full Usage:
tryGetHtml x
Parameters:
HtmlDocument
-
The given document
Returns: HtmlNode option
Modifiers: inline |
Tries to find the html element of the given document.
|
FSharp.Data