HtmlNodeExtensions Type
Static members
| Static member |
Description
|
Full Usage:
HtmlNodeExtensions.Attribute(n, name)
Parameters:
HtmlNode
-
The given node
name : string
-
The name of the attribute to select
Returns: HtmlAttribute
|
Returns the attribute with the given name. If the attribute does not exist then this will throw an exception
|
Full Usage:
HtmlNodeExtensions.AttributeValue(n, name)
Parameters:
HtmlNode
-
The given node
name : string
-
The name of the attribute to get the value from
Returns: string
|
Return the value of the named attribute, or an empty string if not found.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
HtmlNodeExtensions.Descendants(n, predicate, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
predicate : HtmlNode -> bool
-
The predicate for which descendants to return
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: HtmlNode seq
|
|
|
|
Gets all of the descendants of the current node, which match the given name The current node is also considered in the comparison
|
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsAndSelf(n, names, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
names : string seq
-
The set of names by which to map the descendants
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: HtmlNode seq
|
Gets all of the descendants of the current node, which match the given set of names The current node is also considered in the comparison
|
|
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsAndSelf(n, predicate, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
predicate : HtmlNode -> bool
-
The predicate for which descendants to return
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: HtmlNode seq
|
Gets all of the descendants of the current node that satisfy the predicate The current node is also considered in the comparison
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsAndSelfWithPath(n, name, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
name : string
-
The name by which to map the descendants
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of the current node, which match the given name The current node is also considered in the comparison
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsAndSelfWithPath(n, names, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
names : string seq
-
The set of names by which to map the descendants
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of the current node, which match the given set of names The current node is also considered in the comparison
|
|
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsAndSelfWithPath(n, predicate, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
predicate : HtmlNode -> bool
-
The predicate for which descendants to return
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of the current node that satisfy the predicate The current node is also considered in the comparison |
|
|
Full Usage:
HtmlNodeExtensions.DescendantsWithPath(n, name, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
name : string
-
The name by which to map the descendants
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsWithPath(n, names, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
names : string seq
-
The set of names by which to map the descendants
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of the current node, which match the given set of names
|
|
|
|
|
Full Usage:
HtmlNodeExtensions.DescendantsWithPath(n, predicate, recurseOnMatch)
Parameters:
HtmlNode
-
The given node
predicate : HtmlNode -> bool
-
The predicate for which descendants to return
recurseOnMatch : bool
-
If a match is found continues down the tree matching child elements
Returns: (HtmlNode * HtmlNode list) seq
|
|
|
|
|
|
|
|
|
|
Full Usage:
HtmlNodeExtensions.HasAttribute(n, name, value)
Parameters:
HtmlNode
-
The given node
name : string
-
The name of the attribute
value : string
-
The value of the attribute
Returns: bool
|
Returns true if the current node has an attribute that matches both the name and the value
|
Full Usage:
HtmlNodeExtensions.HasClass(n, cssClass)
Parameters:
HtmlNode
cssClass : string
Returns: bool
|
Returns true if the current node has the specified class
|
|
|
Full Usage:
HtmlNodeExtensions.HasName(n, name)
Parameters:
HtmlNode
name : string
Returns: bool
|
|
|
|
|
|
Full Usage:
HtmlNodeExtensions.TryGetAttribute(n, name)
Parameters:
HtmlNode
-
The given node
name : string
-
The name of the attribute to select
Returns: HtmlAttribute option
|
Tries to select an attribute with the given name from the current node.
|
FSharp.Data