HtmlNode Module
Functions and values
| Function or value |
Description
|
Full Usage:
attribute name n
Parameters:
string
-
The name of the attribute to select
n : HtmlNode
-
The given node
Returns: HtmlAttribute
Modifiers: inline |
Returns the attribute with the given name. If the attribute does not exist then this will throw an exception
|
Full Usage:
attributeValue name n
Parameters:
string
-
The name of the attribute to get the value from
n : HtmlNode
-
The given node
Returns: string
Modifiers: inline |
Return the value of the named attribute, or an empty string if not found.
|
|
|
|
|
|
|
|
Gets all of the descendants of this node that statisfy the given predicate The current node is also considered in the comparison
|
|
Finds all of the descendant nodes of this nodes that match the given set of names The current node is also considered in the comparison
|
Full Usage:
descendantsAndSelfNamedWithPath recurseOnMatch names n
Parameters:
bool
-
If a match is found continues down the tree matching child elements
names : string seq
-
The set of names to match
n : HtmlNode
-
The given node
Returns: (HtmlNode * HtmlNode list) seq
Modifiers: inline |
Finds all of the descendant nodes of this nodes that match the given set of names The current node is also considered in the comparison
|
Full Usage:
descendantsAndSelfWithPath recurseOnMatch predicate n
Parameters:
bool
-
If a match is found continues down the tree matching child elements
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
n : HtmlNode
-
The given node
Returns: (HtmlNode * HtmlNode list) seq
|
Gets all of the descendants of this node that statisfy the given predicate The current node is also considered in the comparison |
|
|
|
|
Full Usage:
descendantsWithPath recurseOnMatch predicate n
Parameters:
bool
-
If a match is found continues down the tree matching child elements
predicate : HtmlNode -> bool
-
The predicate by which to match the nodes to return
n : HtmlNode
-
The given node
Returns: (HtmlNode * HtmlNode list) seq
|
|
|
|
|
|
|
|
Full Usage:
hasAttribute name value n
Parameters:
string
-
The name of the attribute
value : string
-
The value of the attribute
n : HtmlNode
-
The given html node
Returns: bool
Modifiers: inline |
Returns true if the current node has an attribute that matches both the name and the value
|
Full Usage:
hasClass cssClass n
Parameters:
string
n : HtmlNode
Returns: bool
Modifiers: inline |
Returns true if the current node has the specified class
|
|
|
Full Usage:
hasName expectedName n
Parameters:
string
n : HtmlNode
Returns: bool
Modifiers: inline |
Returns true if the current node has the specified name
|
|
|
Full Usage:
innerTextExcluding exclusions n
Parameters:
string list
n : HtmlNode
Returns: string
|
|
Full Usage:
tryGetAttribute name n
Parameters:
string
-
The name of the attribute to return.
n : HtmlNode
-
The given node
Returns: HtmlAttribute option
Modifiers: inline |
Tries to return an attribute that exists on the current node
|
FSharp.Data