JsonSaveOptions Type
Specifies the formatting behaviour of JSON values
Record fields
| Record Field |
Description
|
|
Print the JsonValue in one line in a compact way, but place a single space after every comma https://github.com/fsprojects/FSharp.Data/issues/1482
|
|
Print the JsonValue in one line in a compact way
|
|
Format (indent) the JsonValue
|
FSharp.Data