Logo FSharp.Data

InferedMultiplicity Type

For heterogeneous types (types that have multiple possible forms such as differently named XML nodes or records and arrays mixed together) this type represents the number of occurrences of individual forms

Union cases

Union case Description

Multiple

Full Usage: Multiple

OptionalSingle

Full Usage: OptionalSingle

Single

Full Usage: Single

Instance members

Instance member Description

this.IsMultiple

Full Usage: this.IsMultiple

Returns: bool
Returns: bool

this.IsOptionalSingle

Full Usage: this.IsOptionalSingle

Returns: bool
Returns: bool

this.IsSingle

Full Usage: this.IsSingle

Returns: bool
Returns: bool

Type something to start searching.