Indicator Type
Indicator data
Instance members
| Instance member |
Description
|
Full Usage:
this.Code
Returns: string
|
Get the code for the country or region of the indicator
|
Full Usage:
this.Description
Returns: string
|
Get the description of the indicator
|
Full Usage:
this.IndicatorCode
Returns: string
|
Get the code for the indicator
|
Full Usage:
this[year]
Parameters:
int
Returns: float
|
Get the indicator value for the given year. If there's no data for that year, NaN is returned
|
Full Usage:
this.Name
Returns: string
|
Get the name of the indicator
|
Full Usage:
this.Source
Returns: string
|
Get the source of the indicator
|
Full Usage:
this.TryGetValueAt
Parameters:
int
Returns: float option
|
Get the indicator value for the given year, if present
|
|
Get the values for the indicator (without years)
|
|
Get the years for which the indicator has values
|
FSharp.Data