InferedMultiplicity Type
For heterogeneous types (types that have multiple possible forms such as differently named XML nodes or records and arrays mixed together) this type represents the number of occurrences of individual forms
Union cases
| Union case |
Description
|
Full Usage:
Multiple
|
|
Full Usage:
OptionalSingle
|
|
Full Usage:
Single
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsMultiple
Returns: bool
|
|
Full Usage:
this.IsOptionalSingle
Returns: bool
|
|
Full Usage:
this.IsSingle
Returns: bool
|
|
FSharp.Data